#
# Copyright (C) 2025 Indiscale GmbH <info@indiscale.com>
# Copyright (C) 2025 Henrik tom Wörden <h.tomwoerden@indiscale.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
import linkahead as db
import logging

from caosadvancedtools.datainconsistency import DataInconsistencyError

from .utils import CONSTANTS, get_column_header_name, get_entity_name
from .sample_upload_column_definitions import use_custom_names

logger = logging.getLogger("caosadvancedtools")

def check_column_names(names: list[str]) -> None:
    event_and_position_properties = use_custom_names([
        "Campaign",
        "Biome",
        "Device",
        "Elevation start",
        "Elevation stop",
        "End date",
        "responsible_person_event",
        "igsn_doi_prop",
        "Latitude start",
        "Latitude stop",
        "Level",
        "locality_description_prop",
        "locality_name_prop",
        "Longitude start",
        "Longitude stop",
        "Sphere",
        "Start date",
    ])
    needs_events = False
    for name in names:
        if name in event_and_position_properties:
            needs_events = True
    appended = []
    if needs_events:
        for name in use_custom_names([
            "Longitude start",
            "Latitude start",
            "Elevation start",
            "Start date",
        ]):
            if name not in names:
                names.append(name)
                appended.append(name)

    if appended:
        logger.warning(
            "The following columns were added in order to allow consitent data insertion:\n"
            f"{', '.join(appended)}"
        )
